package com.slibra.web.controller.business;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.slibra.common.annotation.Log;
import com.slibra.common.core.controller.BaseController;
import com.slibra.common.core.domain.AjaxResult;
import com.slibra.common.enums.BusinessType;
import com.slibra.business.domain.TNeighborhood;
import com.slibra.business.service.ITNeighborhoodService;
import com.slibra.common.utils.poi.ExcelUtil;
import com.slibra.common.core.page.TableDataInfo;

/**
 * 服务小区Controller
 * 
 * @author slibra
 * @date 2024-11-05
 */
@RestController
@RequestMapping("/business/neighborhood")
public class TNeighborhoodController extends BaseController
{
    @Autowired
    private ITNeighborhoodService tNeighborhoodService;

    /**
     * 查询服务小区列表
     */
    @PreAuthorize("@ss.hasPermi('business:neighborhood:list')")
    @GetMapping("/list")
    public TableDataInfo list(TNeighborhood tNeighborhood)
    {
        startPage();
        List<TNeighborhood> list = tNeighborhoodService.selectTNeighborhoodList(tNeighborhood);
        return getDataTable(list);
    }

    /**
     * 导出服务小区列表
     */
    @PreAuthorize("@ss.hasPermi('business:neighborhood:export')")
    @Log(title = "服务小区", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TNeighborhood tNeighborhood)
    {
        List<TNeighborhood> list = tNeighborhoodService.selectTNeighborhoodList(tNeighborhood);
        ExcelUtil<TNeighborhood> util = new ExcelUtil<TNeighborhood>(TNeighborhood.class);
        util.exportExcel(response, list, "服务小区数据");
    }

    /**
     * 获取服务小区详细信息
     */
    @PreAuthorize("@ss.hasPermi('business:neighborhood:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tNeighborhoodService.selectTNeighborhoodById(id));
    }

    /**
     * 新增服务小区
     */
    @PreAuthorize("@ss.hasPermi('business:neighborhood:add')")
    @Log(title = "服务小区", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TNeighborhood tNeighborhood)
    {
        tNeighborhood.setCreateBy(getUsername());
        return toAjax(tNeighborhoodService.insertTNeighborhood(tNeighborhood));
    }

    /**
     * 修改服务小区
     */
    @PreAuthorize("@ss.hasPermi('business:neighborhood:edit')")
    @Log(title = "服务小区", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TNeighborhood tNeighborhood)
    {
        tNeighborhood.setUpdateBy(getUsername());
        return toAjax(tNeighborhoodService.updateTNeighborhood(tNeighborhood));
    }

    /**
     * 删除服务小区
     */
    @PreAuthorize("@ss.hasPermi('business:neighborhood:remove')")
    @Log(title = "服务小区", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tNeighborhoodService.deleteTNeighborhoodByIds(ids));
    }
}
