package com.slibra.common.core.domain;

import java.math.BigDecimal;
import java.util.Date;

import com.alibaba.fastjson2.annotation.JSONField;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.slibra.common.annotation.Excel;
import com.slibra.common.core.domain.BaseEntity;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * 信义日报数据对象 t_xinyi_daily
 * 
 * @author slibra
 * @date 2024-04-13
 */
@Builder
@Data
@AllArgsConstructor
@NoArgsConstructor
public class TXinyiDaily extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    @JSONField(name = "ID")
    private Long ID;

    /** 化验日期 */
    @Excel(name = "化验日期")
    @JSONField(name = "testDate")
    private String testDate;

    /** 化验日期-小时 */
    @Excel(name = "化验日期-小时")
    @JSONField(name = "testHour")
    private String testHour;

    /** 化验时间（2023/12/13 5:00:00格式的） */
    @Excel(name = "化验时间", readConverterExp = "2=023/12/13,5=:00:00格式的")
    @JSONField(name = "testTime")
    private String testTime;

    /** $column.columnComment */
    @Excel(name = "${comment}", readConverterExp = "$column.readConverterExp()")
    @JSONField(name = "SORT")
    private Long SORT;

    /** 进水化学需氧量 COD */
    @Excel(name = "进水化学需氧量 COD")
    @JSONField(name = "jsCod")
    private BigDecimal jsCod;

    /** 进水酸碱度pH */
    @Excel(name = "进水酸碱度pH")
    @JSONField(name = "jsPh")
    private BigDecimal jsPh;

    /** 进水生化需氧量BOD₅ */
    @Excel(name = "进水生化需氧量BOD₅")
    @JSONField(name = "jsBod5")
    private BigDecimal jsBod5;

    /** 进水悬浮物 SS */
    @Excel(name = "进水悬浮物 SS")
    @JSONField(name = "jsSs")
    private BigDecimal jsSs;

    /** 进水氨氮 NH₃-N */
    @Excel(name = "进水氨氮 NH₃-N")
    @JSONField(name = "jsNh3")
    private BigDecimal jsNh3;

    /** 进水总氮TN */
    @Excel(name = "进水总氮TN")
    @JSONField(name = "jsTn")
    private BigDecimal jsTn;

    /** 进水总磷TP */
    @Excel(name = "进水总磷TP")
    @JSONField(name = "jsTp")
    private BigDecimal jsTp;

    /** 进水粪菌群（大肠杆菌） */
    @Excel(name = "进水粪菌群", readConverterExp = "大=肠杆菌")
    @JSONField(name = "jsDcgj")
    private BigDecimal jsDcgj;

    /** 出水化学需氧量COD */
    @Excel(name = "出水化学需氧量COD")
    @JSONField(name = "csCod")
    private BigDecimal csCod;

    /** 出水酸碱度pH */
    @Excel(name = "出水酸碱度pH")
    @JSONField(name = "csPh")
    private BigDecimal csPh;

    /** 出水生化需氧量BOD₅ */
    @Excel(name = "出水生化需氧量BOD₅")
    @JSONField(name = "csBod5")
    private BigDecimal csBod5;

    /** 出水悬浮物SS */
    @Excel(name = "出水悬浮物SS")
    @JSONField(name = "csSs")
    private BigDecimal csSs;

    /** 出水氨氮 NH₃-N */
    @Excel(name = "出水氨氮 NH₃-N")
    @JSONField(name = "csNh3")
    private BigDecimal csNh3;

    /** 出水总氮TN */
    @Excel(name = "出水总氮TN")
    @JSONField(name = "csTn")
    private BigDecimal csTn;

    /** 出水总磷TP */
    @Excel(name = "出水总磷TP")
    @JSONField(name = "csTp")
    private BigDecimal csTp;

    /** 出水粪菌群（大肠杆菌） */
    @Excel(name = "出水粪菌群", readConverterExp = "大=肠杆菌")
    @JSONField(name = "csDcgj")
    private BigDecimal csDcgj;

    /** 进水水温 */
    @Excel(name = "进水水温")
    @JSONField(name = "jsSw")
    private BigDecimal jsSw;

    /** 出水水温 */
    @Excel(name = "出水水温")
    @JSONField(name = "csSw")
    private BigDecimal csSw;

    /** 生化池好氧池#1 酸碱度pH */
    @Excel(name = "生化池好氧池#1 酸碱度pH")
    @JSONField(name = "shcOnePh")
    private BigDecimal shcOnePh;

    /** 生化池好氧池#2 酸碱度pH */
    @Excel(name = "生化池好氧池#2 酸碱度pH")
    @JSONField(name = "shcTwoPh")
    private BigDecimal shcTwoPh;

    /** 生化池好氧池#1 污泥沉降比SV% */
    @Excel(name = "生化池好氧池#1 污泥沉降比SV%")
    @JSONField(name = "shcHyOneSv")
    private BigDecimal shcHyOneSv;

    /** 生化池好氧池#2 污泥沉降比SV% */
    @Excel(name = "生化池好氧池#2 污泥沉降比SV%")
    @JSONField(name = "shcHyTwoSv")
    private BigDecimal shcHyTwoSv;

    /** 生化池好氧池#1 污泥体积指数SVI */
    @Excel(name = "生化池好氧池#1 污泥体积指数SVI")
    @JSONField(name = "shcHyOneSvi")
    private BigDecimal shcHyOneSvi;

    /** 生化池好氧池#2 污泥体积指数SVI */
    @Excel(name = "生化池好氧池#2 污泥体积指数SVI")
    @JSONField(name = "shcHyTwoSvi")
    private BigDecimal shcHyTwoSvi;

    /** 生化池好氧池#1 污泥浓度MLSS */
    @Excel(name = "生化池好氧池#1 污泥浓度MLSS")
    @JSONField(name = "shcHyOneMlss")
    private BigDecimal shcHyOneMlss;

    /** 生化池好氧池#2 污泥浓度MLSS */
    @Excel(name = "生化池好氧池#2 污泥浓度MLSS")
    @JSONField(name = "shcHyTwoMlss")
    private BigDecimal shcHyTwoMlss;

    /** 生化池好氧池#1 挥发性污泥浓度MLVSS */
    @Excel(name = "生化池好氧池#1 挥发性污泥浓度MLVSS")
    @JSONField(name = "shcHyOneMlvss")
    private BigDecimal shcHyOneMlvss;

    /** 生化池好氧池#2 挥发性污泥浓度MLVSS */
    @Excel(name = "生化池好氧池#2 挥发性污泥浓度MLVSS")
    @JSONField(name = "shcHyTwoMlvss")
    private BigDecimal shcHyTwoMlvss;

    /** 生化池厌氧池#1 溶解氧DO */
    @Excel(name = "生化池厌氧池#1 溶解氧DO")
    @JSONField(name = "shcYyOneDo")
    private BigDecimal shcYyOneDo;

    /** 生化池厌氧池#2 溶解氧DO */
    @Excel(name = "生化池厌氧池#2 溶解氧DO")
    @JSONField(name = "shcYyTwoDo")
    private BigDecimal shcYyTwoDo;

    /** 生化池缺氧池#1 溶解氧DO */
    @Excel(name = "生化池缺氧池#1 溶解氧DO")
    @JSONField(name = "shcQyOneDo")
    private BigDecimal shcQyOneDo;

    /** 生化池缺氧池#2 溶解氧DO */
    @Excel(name = "生化池缺氧池#2 溶解氧DO")
    @JSONField(name = "shcQyTwoDo")
    private BigDecimal shcQyTwoDo;

    /** 生化池好氧池#1 溶解氧DO */
    @Excel(name = "生化池好氧池#1 溶解氧DO")
    @JSONField(name = "shcHyOneDo")
    private BigDecimal shcHyOneDo;

    /** 生化池好氧池#2 溶解氧DO */
    @Excel(name = "生化池好氧池#2 溶解氧DO")
    @JSONField(name = "shcHyTwoDo")
    private BigDecimal shcHyTwoDo;

    /** 进水量 */
    @Excel(name = "进水量")
    @JSONField(name = "JSL")
    private BigDecimal JSL;

    /** 出水量 */
    @Excel(name = "出水量")
    @JSONField(name = "CSL")
    private BigDecimal CSL;

    /** 深度处理冲洗水量(m³) */
    @Excel(name = "深度处理冲洗水量(m³)")
    @JSONField(name = "SDCLCXSL")
    private BigDecimal SDCLCXSL;

    /** 气水比 */
    @Excel(name = "气水比")
    @JSONField(name = "QSB")
    private BigDecimal QSB;

    /** F/M（污泥负荷） */
    @Excel(name = "F/M", readConverterExp = "污=泥负荷")
    @JSONField(name = "fM")
    private BigDecimal fM;

    /** 厌氧区停留时间 HRT */
    @Excel(name = "厌氧区停留时间 HRT")
    @JSONField(name = "yyHrt")
    private BigDecimal yyHrt;

    /** 好氧区停留时间HRT */
    @Excel(name = "好氧区停留时间HRT")
    @JSONField(name = "hyHrt")
    private BigDecimal hyHrt;

    /** 缺氧区停留时间 HRT */
    @Excel(name = "缺氧区停留时间 HRT")
    @JSONField(name = "qyHrt")
    private BigDecimal qyHrt;

    /** 内回流r */
    @Excel(name = "内回流r")
    @JSONField(name = "nhlR")
    private BigDecimal nhlR;

    /** 外回流R */
    @Excel(name = "外回流R")
    @JSONField(name = "whlR")
    private BigDecimal whlR;

    /** 污泥龄SRT */
    @Excel(name = "污泥龄SRT")
    @JSONField(name = "SRT")
    private BigDecimal SRT;

    /** 产泥率 */
    @Excel(name = "产泥率")
    @JSONField(name = "CNL")
    private BigDecimal CNL;

    /** 投药前 BOD₅/TN */
    @Excel(name = "投药前 BOD₅/TN")
    @JSONField(name = "tyqBod5Tn")
    private BigDecimal tyqBod5Tn;

    /** 投药后 BOD₅/TN */
    @Excel(name = "投药后 BOD₅/TN")
    @JSONField(name = "tyhBod5Tn")
    private BigDecimal tyhBod5Tn;

    /** 好氧池溶解氧集合 */
    @Excel(name = "好氧池溶解氧集合")
    @JSONField(name = "hycRjyAll")
    private String hycRjyAll;

    /** 好氧池污泥浓度集合 */
    @Excel(name = "好氧池污泥浓度集合")
    @JSONField(name = "hycWnndAll")
    private String hycWnndAll;

    /** 厌氧池溶解氧集合 */
    @Excel(name = "厌氧池溶解氧集合")
    @JSONField(name = "yycRjyAll")
    private String yycRjyAll;

    /** 缺氧池溶解氧集合 */
    @Excel(name = "缺氧池溶解氧集合")
    @JSONField(name = "qycRjyAll")
    private String qycRjyAll;

    /** 污泥沉降比集合 */
    @Excel(name = "污泥沉降比集合")
    @JSONField(name = "wncjbAll")
    private String wncjbAll;

    /** 污泥体积指数集合 */
    @Excel(name = "污泥体积指数集合")
    @JSONField(name = "wntjzsAll")
    private String wntjzsAll;

    /** 挥发性污泥浓度集合 */
    @Excel(name = "挥发性污泥浓度集合")
    @JSONField(name = "hfxwnndAll")
    private String hfxwnndAll;

    /** 创建时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd")
    @JSONField(name = "createdTime")
    private Date createdTime;

    //2024年5月26日11:54:08  新增的字段
    /** 出泥量(m³) */
    @Excel(name = "出泥量(m³)")
    @JSONField(name = "CHUNILIANG")
    private BigDecimal CHUNILIANG;

    /** 出泥含水率(%) */
    @Excel(name = "出泥含水率(%)")
    @JSONField(name = "CNHSL")
    private BigDecimal CNHSL;

    /** 干污泥量(m³) */
    @Excel(name = "干污泥量(m³)")
    @JSONField(name = "GWNL")
    private BigDecimal GWNL;

    /** 电费 */
    @Excel(name = "电费")
    @JSONField(name = "DF")
    private BigDecimal DF;

    /** 絮凝剂费 */
    @Excel(name = "絮凝剂费")
    @JSONField(name = "XNJF")
    private BigDecimal XNJF;

    /** 除磷费 */
    @Excel(name = "除磷费")
    @JSONField(name = "CLF")
    private BigDecimal CLF;

    /** 碳源费 */
    @Excel(name = "碳源费")
    @JSONField(name = "TYF")
    private BigDecimal TYF;

    /** 消毒剂费 */
    @Excel(name = "消毒剂费")
    @JSONField(name = "XDJF")
    private BigDecimal XDJF;

    /** 其他药剂费 */
    @Excel(name = "其他药剂费")
    @JSONField(name = "QTYJF")
    private BigDecimal QTYJF;

    /** 采暖费 */
    @Excel(name = "采暖费")
    @JSONField(name = "CNF")
    private BigDecimal CNF;

    /** 自来水费 */
    @Excel(name = "自来水费")
    @JSONField(name = "ZLSF")
    private BigDecimal ZLSF;

    /** 直接成本 */
    @Excel(name = "直接成本")
    @JSONField(name = "ZJCB")
    private BigDecimal ZJCB;

    /** 单位成本 */
    @Excel(name = "单位成本")
    @JSONField(name = "DWCB")
    private BigDecimal DWCB;

    //2024年09月10日10:47:07 新增的请求参数
    /**  开始时间 */
    private String timeBegin;

    /** 截止时间 */
    private String timeEnd;
}
